Properties

Struct Properties 

pub struct Properties(/* private fields */);
Compact, constant time reference to Unicode properties for a character.

Implementations

Source

impl Properties

pub fn category(self) -> Category

Returns the category of the character.

pub fn block(self) -> Block

Returns the unicode block that contains the character.

pub fn script(self) -> Script

Returns the script to which the character belongs.

pub fn combining_class(self) -> u8

Returns the canonical combining class of the character.

pub fn bidi_class(self) -> BidiClass

Returns the bidirectional type of the character.

pub fn joining_type(self) -> JoiningType

Returns the joining type of the character.

pub fn cluster_break(self) -> ClusterBreak

Returns the cluster break property for the character.

pub fn word_break(self) -> WordBreak

Returns the word break property for the character.

pub fn line_break(self) -> LineBreak

Returns the line break property for the character.

pub fn is_emoji(self) -> bool

Returns true if the character is an emoji.

pub fn is_extended_pictographic(self) -> bool

Returns true if the character is an extended pictographic symbol.

pub fn is_open_bracket(self) -> bool

Returns true if the character is an opening bracket.

pub fn is_close_bracket(self) -> bool

Returns true if the character is a closing bracket.